@@ -553,6 +553,14 @@ console.log('hello!');}/*! Copyright blah blah
              */\n\nvar a;"""
         self.assertMinified(original, expected)
 
+    def test_issue_14(self):
+        original = 'return x / 1;'
+        self.assertMinified(original, 'return x/1;')
+        
+    def test_issue_14_with_char_from_return(self):
+        original = 'return r / 1;'
+        self.assertMinified(original, 'return r/1;')
+
 
 class RegexTests(unittest.TestCase):
 
